<?php

namespace App\Filament\Admin\Resources;

use App\Filament\Admin\Resources\SuperInvoiceResource\Pages;
use App\Models\Invoice;
use Filament\Forms\Components\Select;
use Filament\Forms\Components\TextInput;
use Filament\Forms\Form;
use Filament\Resources\Resource;
use Filament\Tables;
use Filament\Tables\Columns\TextColumn;
use Filament\Tables\Table;

class SuperInvoiceResource extends Resource
{
    protected static ?string $model = Invoice::class;

    protected static ?string $navigationIcon = 'heroicon-o-rectangle-stack';

    public static function form(Form $form): Form
    {
        return $form
            ->columns(3)
            ->schema([
                TextInput::make('id')
                    ->disabled()
                    ->columnSpan(1)
                    ->prefix('#')
                    ->visible(fn ($context) => $context === 'edit'),
                TextInput::make('name')
                    ->columnSpan(2),
                Select::make('user')
                    ->searchable()
                    ->columnSpan(1)
                    ->preload()
                    ->helperText('You can create an invoice as a given user.')
                    ->relationship(name: 'user', titleAttribute: 'name'),
            ]);
    }

    public static function table(Table $table): Table
    {
        return $table
            ->columns([
                TextColumn::make('id')->label('Ref')->sortable(),
                TextColumn::make('name')->searchable(),
                TextColumn::make('user.name')->searchable(),
                TextColumn::make('created_at')->date(),
            ])
            ->filters([
                //
            ])
            ->actions([
                Tables\Actions\EditAction::make(),

            ])
            ->bulkActions([
                Tables\Actions\BulkActionGroup::make([
                    Tables\Actions\DeleteBulkAction::make(),
                ]),
            ]);
    }

    public static function getRelations(): array
    {
        return [
            //
        ];
    }

    public static function getPages(): array
    {
        return [
            'index' => Pages\ListSuperInvoices::route('/'),
            'create' => Pages\CreateSuperInvoice::route('/create'),
            'edit' => Pages\EditSuperInvoice::route('/{record}/edit'),
        ];
    }
}
